@@ -1,13 +1,16 @@
 from typing import Type, Union, Text, List, get_args, get_origin, Any
 from sqlalchemy.sql.sqltypes import NullType, DateTime, Float, JSON, Integer, String
+from sqlalchemy.dialects.mysql.types import TIMESTAMP
 from .util import Datetime
 from dataclasses import dataclass, is_dataclass, fields, Field, field
 from sqlalchemy.types import TypeEngine
 
+VARCHAR_LEN = 256
+
 alchamey_type = {
-    Text: String,
-    List: String,
-    Datetime: DateTime,
+    Text: lambda *a,**kw: String(length=VARCHAR_LEN),
+    List: String(length=VARCHAR_LEN),
+    Datetime:DateTime,
     float: Float,
     int: Integer,
     dict: JSON
@@ -35,4 +38,4 @@ def python_to_alechamy(a_type):
     except TypeError:
         ...
 
-    return alchamey_type.get(a_type, String)
\ No newline at end of file
+    return alchamey_type.get(a_type, String(length=VARCHAR_LEN))
\ No newline at end of file
